==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-appearance/translations/lxqt-config-appearance_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="147"/>
        <source>GTK themes</source>
        <translation>GTK temaları</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="148"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; üzerine yazıldı.&lt;/p&gt;&lt;p&gt;&apos;%2&apos; dizininde eski ayarlarınızın bir kopyasını bulabilirsiniz.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Kullanıcı arayüzü öntanımlı yazıtipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Yazı tipi adı:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Biçem:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Yazıtipi boyutu:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Kalın eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Aşağıdaki ayarlar yalnızca yeni başlatılan uygulamaları etkiler</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Yazıtipi yumuşatması kullan</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Yazıtipi ipucu biçemi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Hafif</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Tam</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Yazı tipi ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Çözünürlük (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Otomatik ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Alt-piksel yumuşatma:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Ayarları</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG simge temasının KDE eklentisi -&gt; Aşağıdaki Renk Şeması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Simgeleri gereç biçemine (palet) göre renklendir</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Kullanıcı tanımlı duvar kağıdını geçersiz kıl</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Yapılandırma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Font</source>
        <translation>Yazıtipi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Cursor</source>
        <translation>İmleç</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="42"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK temalarını ayarla (GTK yapılandırma dosyaları üzerine yazılacak!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="62"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 Teması</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="72"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 Teması</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="82"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Tekdüzen temalı girişimleri denemek için, ya tüm listelerde benzer stil / temayı (varsa) seçin ya da GTK temalarını taklit etmek için &apos;gtk2&apos; Qt stilini (varsa) seçin.

GTK uygulamalarının temaları anında uygulamasına yardımcı olmak için &apos;xsettingsd&apos; &apos;nin kurulu olduğundan emin olun.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="99"/>
        <source>Toolbar button style:</source>
        <translation>Araç çubuğu düğme stili:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="107"/>
        <source>Only display the icon</source>
        <translation>Sadece simgeyi göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>Only display the text</source>
        <translation>Sadece metni göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="117"/>
        <source>The text appears beside the icon</source>
        <translation>Simgenin yanında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>The text appears under the icon</source>
        <translation>Simge altında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="127"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="135"/>
        <source>Activate item on single click</source>
        <translation>Tek tıklamayla öğeyi etkinleştir</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="145"/>
        <source>Qt Style</source>
        <translation>Qt Biçemi</translation>
    </message>
</context>
</TS>

==> lxqt-config-1.0.0.tar.xz: lxqt-config-1.0.0/lxqt-config-appearance/translations/lxqt-config-appearance_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>Rengi değiştirmek için tıklayın.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Renk Seç</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK temaları</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; üzerine yazıldı.&lt;/p&gt;&lt;p&gt;&apos;%2&apos; dizininde eski ayarlarınızın bir kopyasını bulabilirsiniz.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Kullanıcı arayüzü öntanımlı yazıtipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Yazı tipi adı:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Biçem:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Yazıtipi boyutu:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Kalın eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Aşağıdaki ayarlar yalnızca yeni başlatılan uygulamaları etkiler</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Yazıtipi yumuşatması kullan</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Yazıtipi ipucu biçemi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Hafif</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Tam</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Yazı tipi ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Çözünürlük (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Otomatik ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Alt-piksel yumuşatma:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Ayarları</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG simge temasının KDE eklentisi -&gt; Aşağıdaki Renk Şeması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Simgeleri gereç biçemine (palet) göre renklendir</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Kullanıcı tanımlı duvar kağıdını geçersiz kıl</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Yapılandırma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>Font</source>
        <translation>Yazıtipi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Cursor</source>
        <translation>İmleç</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt Paleti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Bazı Qt biçemleri bu renkleri görmezden gelebilir.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>Pencere:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>Görünüm:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>Seçim:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>Bağlantı:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>Pencere Metni:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>Metni Görüntüle:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>Seçilen Metin:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>Ziyaret Edilen Bağlantı:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Varsayılan Palet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="268"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK temalarını ayarla (GTK yapılandırma dosyaları üzerine yazılacak!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="288"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 Teması</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="298"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 Teması</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="308"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Tekdüzen temalı girişimleri denemek için, ya tüm listelerde benzer stil / temayı (varsa) seçin ya da GTK temalarını taklit etmek için &apos;gtk2&apos; Qt stilini (varsa) seçin.

GTK uygulamalarının temaları anında uygulamasına yardımcı olmak için &apos;xsettingsd&apos; &apos;nin kurulu olduğundan emin olun.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>Toolbar button style:</source>
        <translation>Araç çubuğu düğme stili:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="333"/>
        <source>Only display the icon</source>
        <translation>Sadece simgeyi göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="338"/>
        <source>Only display the text</source>
        <translation>Sadece metni göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="343"/>
        <source>The text appears beside the icon</source>
        <translation>Simgenin yanında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="348"/>
        <source>The text appears under the icon</source>
        <translation>Simge altında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="353"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="361"/>
        <source>Activate item on single click</source>
        <translation>Tek tıklamayla öğeyi etkinleştir</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt Biçemi</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="294"/>
        <location filename="../styleconfig.cpp" line="304"/>
        <source>Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="294"/>
        <source>Palette name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="305"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="374"/>
        <source>Remove Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="375"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
